MODULE trdicp_oce
   !!======================================================================
   !!                   ***  MODULE trdicp_oce  ***
   !! Ocean trends :   set tracer and momentum trend variables
   !!======================================================================

   !!----------------------------------------------------------------------
   !!   'key_trdtra'   or                         tracer trends diagnostics
   !!   'key_trddyn'                            momentum trends diagnostics
   !!----------------------------------------------------------------------
   USE par_oce                 ! ocean parameters

   IMPLICIT NONE
   PUBLIC

   !! * Shared module variables
#if  defined key_trdtra   &&   defined key_trddyn    ||   defined key_esopa
   LOGICAL, PARAMETER ::   lk_trdtra = .TRUE.    !: tracers  trend flag
   LOGICAL, PARAMETER ::   lk_trddyn = .TRUE.    !: momentum trend flag
#elif  defined key_trdtra
   LOGICAL, PARAMETER ::   lk_trdtra = .TRUE.    !: tracers  trend flag
   LOGICAL, PARAMETER ::   lk_trddyn = .FALSE.   !: momentum trend flag
#elif  defined key_trddyn
   LOGICAL, PARAMETER ::   lk_trdtra = .FALSE.   !: tracers  trend flag
   LOGICAL, PARAMETER ::   lk_trddyn = .TRUE.    !: momentum trend flag
#else
   LOGICAL, PARAMETER ::   lk_trdtra = .FALSE.   !: tracers  trend flag
   LOGICAL, PARAMETER ::   lk_trddyn = .FALSE.   !: momentum trend flag
#endif

   !! Tracers trends diagnostics parameters
   !!---------------------------------------------------------------------
   INTEGER, PARAMETER ::   &  !: => tracer trends indexes <=
        jpicpt_xad =  1,   &  !: x- horizontal advection
        jpicpt_yad =  2,   &  !: y- horizontal advection
        jpicpt_zad =  3,   &  !: z- vertical   advection
        jpicpt_ldf =  4,   &  !: lateral       diffusion
        jpicpt_zdf =  5,   &  !: vertical diffusion (Kz)
        jpicpt_bbc =  6,   &  !: Bottom Boundary Condition (geoth. flux) 
        jpicpt_bbl =  7,   &  !: Bottom Boundary Layer (diffusive/convective)
        jpicpt_npc =  8,   &  !: static instability mixing
        jpicpt_dmp =  9,   &  !: damping
        jpicpt_qsr = 10,   &  !: penetrative solar radiation
        jpicpt_nsr = 11,   &  !: non solar radiation
        jpicpt_zl1 = 12       !: first level vertical flux

   INTEGER, PARAMETER ::   &  !: => Total tracer trends indexes <=
        jptot_tra = 12        !: change it when adding/removing one indice above
   
   !! Momentum trends diagnostics parameters
   !!---------------------------------------------------------------------
   INTEGER, PARAMETER ::   &  !: => dynamic trends indexes <=
        jpicpd_hpg =  1,   &  !: hydrostatic pressure gradient 
        jpicpd_keg =  2,   &  !: kinetic energy gradient
        jpicpd_rvo =  3,   &  !: relative vorticity
        jpicpd_pvo =  4,   &  !: planetary vorticity
        jpicpd_ldf =  5,   &  !: lateral diffusion
        jpicpd_had =  6,   &  !: horizontal advection
        jpicpd_zad =  7,   &  !: vertical advection
        jpicpd_zdf =  8,   &  !: vertical diffusion
        jpicpd_spg =  9,   &  !: surface pressure gradient
        jpicpd_dat = 10,   &  !: damping term
        jpicpd_swf = 11,   &  !: surface wind forcing
        jpicpd_bfr = 12       !: bottom friction 

   INTEGER, PARAMETER ::   &  !: => Total dynamic trends indexes <=
        jptot_dyn = 12        !: change it when adding/removing one indice above
   
#if   defined key_trdtra   ||   defined key_trddyn   ||   defined key_esopa

   !! Variables used for diagnostics
   !!---------------------------------------------------------------------
   REAL(wp) ::   tvolt        !: volume of the whole ocean computed at t-points
   REAL(wp) ::   tvolu        !: volume of the whole ocean computed at u-points
   REAL(wp) ::   tvolv        !: volume of the whole ocean computed at v-points

   !! Tracers trends diagnostics variables
   !!---------------------------------------------------------------------
   REAL(wp), DIMENSION(jptot_tra) ::   tmo, smo         !: tracers trends average 
   REAL(wp), DIMENSION(jptot_tra) ::   t2, s2           !: tracers square trends average 
   
   !! Momentum trends diagnostics variables
   !!---------------------------------------------------------------------
   REAL(wp), DIMENSION(jptot_dyn) ::   umo, vmo         !: momentum trends average 
   REAL(wp), DIMENSION(jptot_dyn) ::   hke              !: momentum square trends average 
   REAL(wp) ::   rpktrd   !: potential to kinetic energy conversion
   REAL(wp) ::   peke     !: conversion potential energy - kinetic energy trend

#endif
   !!----------------------------------------------------------------------
   !!  OPA 9.0 , LOCEAN-IPSL (2005) 
   !! $Id$ 
   !! Software governed by the CeCILL licence (modipsl/doc/NEMO_CeCILL.txt)
   !!======================================================================
END MODULE trdicp_oce
